gocredits

package module
v0.2.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 3, 2024 License: MIT Imports: 19 Imported by: 0

README

gocredits

Forked from original project https://github.com/Songmu/gocredits

MIT License GoDoc

gocredits creates CREDITS file from LICENSE files of dependencies

Synopsis

gocredits . > CREDITS

Description

When distributing built executable in Go, we need to include LICENSE of the dependent libraries into the package, so gocredits bundle them together as a CREDITS file.

To use gocredits, we should use go modules for dependency management.

Installation

go get
% go get github.com/harshavardhana/gocredits/cmd/gocredits

Built binaries are available on GitHub Releases. https://github.com/harshavardhana/gocredits/releases

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Run

func Run(argv []string, outStream, errStream io.Writer) error

Run the gocredits

Types

type MatchResult

type MatchResult struct {
	Template     *Template
	Score        float64
	ExtraWords   []string
	MissingWords []string
}

type Template

type Template struct {
	Title    string
	Nickname string
	Words    map[string]int
}

type Word

type Word struct {
	Text string
	Pos  int
}

Directories

Path Synopsis
cmd
gocredits command

Jump to